src/eric7/MicroPython/WifiDialogs/WifiController.py

branch
mpy_network
changeset 9878
a82014a9e57b
parent 9875
b4512fbcf567
child 9886
1a4f05b0dc00
--- a/src/eric7/MicroPython/WifiDialogs/WifiController.py	Sat Mar 11 15:28:47 2023 +0100
+++ b/src/eric7/MicroPython/WifiDialogs/WifiController.py	Sun Mar 12 14:56:04 2023 +0100
@@ -368,9 +368,10 @@
                 msg,
             )
 
+    @pyqtSlot()
     def __setNetworkTime(self):
         """
         Private method to synchronize the device clock to network time.
         """
         from ..NtpParametersDialog import NtpParametersDialog
 
@@ -368,9 +368,10 @@
     def __setNetworkTime(self):
         """
-        Private method to synchronize the device clock to network time.
+        Private slot to synchronize the device clock to network time.
         """
         from ..NtpParametersDialog import NtpParametersDialog

eric ide

mercurial